@@ -77,9 +77,9 @@
 //! use dxr::axum::http::HeaderMap;
 //! use dxr::{Fault, FromParams, HandlerFn, ToDXR, Value};
 //!
-//! fn hello_handler(params: &[Value], _headers: &HeaderMap) -> Result<Value, Fault> {
+//! fn hello_handler(params: &[Value], _headers: &HeaderMap) -> Result<Option<Value>, Fault> {
 //!     let name = String::from_params(params)?;
-//!     Ok(format!("Handler function says: Hello, {}!", name).to_dxr()?)
+//!     Ok(Some(format!("Handler function says: Hello, {}!", name).to_dxr()?))
 //! }
 //!
 //! use dxr::ServerBuilder;
@@ -129,8 +129,10 @@
 //! - null values (`<nil/>`): mapped to [`Option`]`<T>`, enabled with the `nil` feature
 
 #[cfg(feature = "derive")]
+#[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 pub use dxr_derive::{FromDXR, ToDXR};
 
+#[doc(inline)]
 pub use dxr_shared::{DxrError, Fault, FromDXR, FromParams, ToDXR, ToParams, Value, XML_RPC_DATE_FORMAT};
 
 // re-export chrono: DateTime / Utc are part of the public API
