@@ -1,3 +1,4 @@
+use std::borrow::Cow;
 use std::collections::HashMap;
 use std::fmt::{Debug, Formatter};
 use std::net::SocketAddr;
@@ -15,10 +16,15 @@ pub use handler::*;
 mod shutdown;
 pub use shutdown::*;
 
+/// default server route / path for XML-RPC endpoints
+#[cfg_attr(docsrs, doc(cfg(feature = "server")))]
+pub const DEFAULT_SERVER_ROUTE: &str = "/";
+
 /// builder that takes parameters for constructing a [`Server`]
 #[cfg_attr(docsrs, doc(cfg(feature = "server")))]
 pub struct ServerBuilder {
     addr: SocketAddr,
+    path: Cow<'static, str>,
     handlers: HashMap<&'static str, Box<dyn Handler>>,
     off_switch: Option<Box<dyn ServerOffSwitch>>,
 }
@@ -30,6 +36,7 @@ impl Debug for ServerBuilder {
 
         f.debug_struct("ServerBuilder")
             .field("addr", &self.addr)
+            .field("path", &self.path)
             .field("handlers", &handler_list)
             .field("off_switch", &self.off_switch)
             .finish()
@@ -41,11 +48,21 @@ impl ServerBuilder {
     pub fn new(addr: SocketAddr) -> ServerBuilder {
         ServerBuilder {
             addr,
+            path: Cow::Borrowed(DEFAULT_SERVER_ROUTE),
             handlers: HashMap::new(),
             off_switch: None,
         }
     }
 
+    /// method for overriding the default path / route for the XML-RPC endpoint
+    ///
+    /// The default value is [`/`](DEFAULT_SERVER_ROUTE). Another common value
+    /// is `/RPC2`, which can be set with this method, if necessary.
+    pub fn set_path(mut self, route: &str) -> Self {
+        self.path = Cow::Owned(route.to_owned());
+        self
+    }
+
     /// method for adding a switch that is used to handle graceful shutdown
     ///
     /// To avoid a direct dependency on an async runtime, the value implementing the
@@ -65,12 +82,15 @@ impl ServerBuilder {
     pub fn build(self) -> Server {
         Server {
             addr: self.addr,
+            path: self.path,
             handlers: Arc::new(self.handlers),
             off_switch: self.off_switch,
         }
     }
 }
 
+type Handlers = Arc<HashMap<&'static str, Box<dyn Handler>>>;
+
 /// # XML-RPC server implementation
 ///
 /// This type provides a very simple XML-RPC server implementation. Specify server address,
@@ -78,7 +98,8 @@ impl ServerBuilder {
 #[cfg_attr(docsrs, doc(cfg(feature = "server")))]
 pub struct Server {
     addr: SocketAddr,
-    handlers: Arc<HashMap<&'static str, Box<dyn Handler>>>,
+    path: Cow<'static, str>,
+    handlers: Handlers,
     off_switch: Option<Box<dyn ServerOffSwitch>>,
 }
 
@@ -89,6 +110,7 @@ impl Debug for Server {
 
         f.debug_struct("Server")
             .field("addr", &self.addr)
+            .field("path", &self.path)
             .field("handlers", &handler_list)
             .field("off_switch", &self.off_switch)
             .finish()
@@ -102,35 +124,10 @@ impl Server {
     /// into fault responses.
     pub async fn serve(self) -> Result<(), String> {
         let app = Router::new().route(
-            "/",
-            post({
-                move |body: String, headers: HeaderMap| async move {
-                    if headers.get(CONTENT_LENGTH).is_none() {
-                        return fault_to_response(411, "Content-Length header missing.");
-                    }
-
-                    let call: MethodCall = match quick_xml::de::from_str(&body) {
-                        Ok(call) => call,
-                        Err(error) => {
-                            let e = DxrError::invalid_data(error.to_string());
-                            let f = Fault::new(400, e.to_string());
-                            return fault_to_response(f.code(), f.string());
-                        },
-                    };
-
-                    let handler = match self.handlers.get(call.name()) {
-                        Some(handler) => handler,
-                        None => return fault_to_response(404, "Unknown method."),
-                    };
-
-                    let response = match handler.handle(call.params(), &headers) {
-                        Ok(value) => success_to_response(value),
-                        Err(fault) => fault_to_response(fault.code(), fault.string()),
-                    };
-
-                    response
-                }
-            }),
+            self.path.as_ref(),
+            post(
+                move |body: String, headers: HeaderMap| async move { service(self.handlers.clone(), &body, &headers) },
+            ),
         );
 
         if let Some(switch) = self.off_switch {
@@ -148,6 +145,33 @@ impl Server {
     }
 }
 
+fn service(handlers: Handlers, body: &str, headers: &HeaderMap) -> (StatusCode, HeaderMap, String) {
+    if headers.get(CONTENT_LENGTH).is_none() {
+        return fault_to_response(411, "Content-Length header missing.");
+    }
+
+    let call: MethodCall = match quick_xml::de::from_str(body) {
+        Ok(call) => call,
+        Err(error) => {
+            let e = DxrError::invalid_data(error.to_string());
+            let f = Fault::new(400, e.to_string());
+            return fault_to_response(f.code(), f.string());
+        },
+    };
+
+    let handler = match handlers.get(call.name()) {
+        Some(handler) => handler,
+        None => return fault_to_response(404, "Unknown method."),
+    };
+
+    let response = match handler.handle(call.params(), headers) {
+        Ok(value) => success_to_response(value),
+        Err(fault) => fault_to_response(fault.code(), fault.string()),
+    };
+
+    response
+}
+
 fn response_headers() -> HeaderMap {
     let mut headers = HeaderMap::new();
     headers.insert(CONTENT_TYPE, HeaderValue::from_static("text/xml"));
